@@ -55,7 +55,7 @@ class OutputSizeMixin(SchemaMixin, abc.ABC):
 
 
 class LossMixin:
-    """Mixin to use for `torch.Module`s that can calculate a loss."""
+    """Mixin to use for a `torch.Module` that can calculate a loss."""
 
     def compute_loss(
         self,
@@ -80,7 +80,7 @@ class LossMixin:
 
 
 class MetricsMixin:
-    """Mixin to use for `torch.Module`s that can calculate metrics."""
+    """Mixin to use for a `torch.Module` that can calculate metrics."""
 
     def calculate_metrics(
         self,
@@ -212,7 +212,7 @@ def one_hot_1d(
 
     Args:
         labels (torch.Tensor) : tensor with labels of shape :math:`(N, H, W)`,
-                                where N is batch siz. Each value is an integer
+                                where N is batch size. Each value is an integer
                                 representing correct classification.
         num_classes (int): number of classes in labels.
         device (Optional[torch.device]): the desired device of returned tensor.
